package org.klomp.eclipse.team.ui;

import java.text.MessageFormat;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.SubProgressMonitor;

import org.eclipse.team.core.TeamException;

import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The main plugin class to be used in the desktop.
 */
public class TeamUIPlugin extends AbstractUIPlugin
{
    public final static String ID = "org.klomp.eclipse.team.ui";

    /**
     * The shared instance.
     */
    private static TeamUIPlugin plugin;

    /**
     * Constructor.
     */
    public TeamUIPlugin(IPluginDescriptor descriptor)
    {
        super(descriptor);
        plugin = this;
    }

    /**
     * Returns the shared instance.
     */
    public static TeamUIPlugin getPlugin()
    {
        return plugin;
    }

    /**
     * Returns the workspace instance.
     */
    public static IWorkspace getWorkspace()
    {
        return ResourcesPlugin.getWorkspace();
    }

    /**
     * Returns the string from the plugin's resource bundle, or <code>key</code>
     * if not found.
     */
    public static String getString(String key)
    {
        return getPluginDescriptor().getResourceString(key);
    }

    public static String formatResourceString(String key, String arg)
    {
        MessageFormat fmt = new MessageFormat(getString(key));
        return fmt.format(new String[] { arg });
    }

    public static String formatResourceString(String key, String[] args)
    {
        MessageFormat fmt = new MessageFormat(getString(key));
        return fmt.format(args);
    }

    public static IPluginDescriptor getPluginDescriptor()
    {
        return getPlugin().getDescriptor();
    }

    public static IProgressMonitor monitorFor(IProgressMonitor monitor)
    {
        if (monitor == null)
        {
            return new NullProgressMonitor();
        }
        return monitor;
    }

    public static IProgressMonitor subMonitorFor(IProgressMonitor monitor, int ticks)
    {
        if (monitor == null)
        {
            return new NullProgressMonitor();
        }
        if (monitor instanceof NullProgressMonitor)
        {
            return monitor;
        }
        return new SubProgressMonitor(monitor, ticks);
    }

    /**
     * Convenience method for logging TeamExceptions to the plugin log
     */
    public static void log(TeamException e)
    {
        log(e.getStatus());
    }

    /**
     * Convenience method for logging a status to the plugin log
     */
    public static void log(IStatus status)
    {
        getPlugin().getLog().log(status);
    }

    /**
     * Convenience method for logging an internal error
     */
    public static void logError(String message, Throwable e)
    {
        log(new Status(IStatus.ERROR, ID, 0, message, e));
    }

    /**
     * Convenience method for logging an internal info message.
     */
    public static void logInfo(String message, Throwable e)
    {
        log(new Status(IStatus.INFO, ID, 0, message, e));
    }
}
